summaryrefslogtreecommitdiffstats
path: root/src/include/bootloader/bootloader.H
diff options
context:
space:
mode:
authorBill Hoffa <wghoffa@us.ibm.com>2017-04-10 14:43:51 -0500
committerDaniel M. Crowell <dcrowell@us.ibm.com>2017-05-10 15:33:40 -0400
commit240f26001382001974fff7d62367e58df3f7b1db (patch)
tree482556bd955971c05b942b6a89639f8f187360a0 /src/include/bootloader/bootloader.H
parentb947a1a4119b06ee50287854e5ea974c0926226e (diff)
downloadtalos-hostboot-240f26001382001974fff7d62367e58df3f7b1db.tar.gz
talos-hostboot-240f26001382001974fff7d62367e58df3f7b1db.zip
Include HUID of failed Proc in TI data for certain SBE errors
- Include a generic error pipleline for other future error scenarios to leverage this functionality Change-Id: Icc1399ee93157c7106d394944a3355285a8cd830 RTC: 171865 Reviewed-on: http://ralgit01.raleigh.ibm.com/gerrit1/39072 Reviewed-by: Martin Gloff <mgloff@us.ibm.com> Tested-by: Jenkins Server <pfd-jenkins+hostboot@us.ibm.com> Tested-by: Jenkins OP Build CI <op-jenkins+hostboot@us.ibm.com> Tested-by: FSP CI Jenkins <fsp-CI-jenkins+hostboot@us.ibm.com> Reviewed-by: Prachi Gupta <pragupta@us.ibm.com> Reviewed-by: Daniel M. Crowell <dcrowell@us.ibm.com>
Diffstat (limited to 'src/include/bootloader/bootloader.H')
-rw-r--r--src/include/bootloader/bootloader.H69
1 files changed, 37 insertions, 32 deletions
diff --git a/src/include/bootloader/bootloader.H b/src/include/bootloader/bootloader.H
index ddd39bb0b..afe2acc71 100644
--- a/src/include/bootloader/bootloader.H
+++ b/src/include/bootloader/bootloader.H
@@ -48,41 +48,46 @@ extern "C" void enterHBB(uint64_t i_hbb_hrmor, uint64_t i_hbb_offset);
#define printk(format...)
/**
* @brief Handle setting up to terminate Bootloader
*
* @param[in] i_moduleID ID for module where terminate is occurring
* @param[in] i_reasoncode Reason code for why terminating
* @param[in] i_word7 Data for SRC word 7 / @userdata2[0:31]
* (optional, default is 0)
* @param[in] i_word8 Data for SRC word 8 / @userdata2[32:63]
* (optional, default is 0)
* @param[in] i_executeTI Flag for calling terminateExecuteTI
* (optional, default is true)
* @param[in] i_failAddr Address associated with termination
* (SRC word 6 / @userdata1[32:63],
* optional, default is 0)
*/
inline void bl_terminate(uint8_t i_moduleID,
- uint16_t i_reasoncode,
- uint32_t i_word7 = 0,
- uint32_t i_word8 = 0,
- bool i_executeTI = true,
- uint64_t i_failAddr = 0)
-{
- termWriteSRC(TI_BOOTLOADER,
- i_reasoncode,
- i_failAddr);
-
- termModifySRC(i_moduleID,
- i_word7,
- i_word8);
-
- if(i_executeTI)
+ uint16_t i_reasoncode,
+ uint32_t i_word7 = 0,
+ uint32_t i_word8 = 0,
+ bool i_executeTI = true,
+ uint64_t i_failAddr = 0,
+ uint32_t i_error_info = 0)
{
- terminateExecuteTI();
+ termWriteSRC(TI_BOOTLOADER,
+ i_reasoncode,
+ i_failAddr,
+ i_error_info);
+
+ termModifySRC(i_moduleID,
+ i_word7,
+ i_word8);
+
+ if(i_executeTI)
+ {
+ terminateExecuteTI();
+ }
}
-}
+
/**
* @brief Macro to assert using bl_terminate
OpenPOWER on IntegriCloud
@@ -48,41 +48,46 @@ extern "C" void enterHBB(uint64_t i_hbb_hrmor, uint64_t i_hbb_offset);
#define printk(format...)
-/**
- * @brief Handle setting up to terminate Bootloader
- *
- * @param[in] i_moduleID ID for module where terminate is occurring
- * @param[in] i_reasoncode Reason code for why terminating
- * @param[in] i_word7 Data for SRC word 7 / @userdata2[0:31]
- * (optional, default is 0)
- * @param[in] i_word8 Data for SRC word 8 / @userdata2[32:63]
- * (optional, default is 0)
- * @param[in] i_executeTI Flag for calling terminateExecuteTI
- * (optional, default is true)
- * @param[in] i_failAddr Address associated with termination
- * (SRC word 6 / @userdata1[32:63],
- * optional, default is 0)
- */
+ /**
+ * @brief Handle setting up to terminate Bootloader
+ *
+ * @param[in] i_moduleID ID for module where terminate is occurring
+ * @param[in] i_reasoncode Reason code for why terminating
+ * @param[in] i_word7 Data for SRC word 7 / @userdata2[0:31]
+ * (optional, default is 0)
+ * @param[in] i_word8 Data for SRC word 8 / @userdata2[32:63]
+ * (optional, default is 0)
+ * @param[in] i_executeTI Flag for calling terminateExecuteTI
+ * (optional, default is true)
+ * @param[in] i_failAddr Address associated with termination
+ * (SRC word 6 / @userdata1[32:63],
+ * optional, default is 0)
+ * @param[in] i_error_info Optional error data to go in the TI
+ * data area
+ * */
inline void bl_terminate(uint8_t i_moduleID,